#
# spec file for package thin-provisioning-tools
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           thin-provisioning-tools
VCS: https://src.suse.de/pool/thin-provisioning-tools#6b2b79ed28121c2745ba4ac58c2f6786952f4079
Version:        0.9.0
Release:        2.10
Summary:        Thin Provisioning Tools
License:        GPL-3.0-only
Group:          System/Base
URL:            https://github.com/jthornber/thin-provisioning-tools/
Source0:        https://github.com/jthornber/thin-provisioning-tools/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-build-c++
BuildRequires:  libaio-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libexpat-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  suse-module-tools
Requires(post): coreutils
Requires(postun):coreutils
Conflicts:      device-mapper < 1.02.115

%description
A suite of tools for thin provisioning on Linux.

%prep
%autosetup

%build
export CXXFLAGS="${CXXFLAGS} -fPIC"
export LDFLAGS="-pie"
autoreconf -fiv
%configure \
  --bindir=%{_sbindir} \
  --enable-testing \
  --enable-dev-tools \
  --with-optimisation="%{optflags}" \
# In generated Makefile V=@ is used, in order to achieve verbose build ve
# must override it as V=""
make %{?_smp_mflags} V=""

%install
%make_install STRIP="/bin/true"

%post
%{?regenerate_initrd_post}

%postun
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%files
%license COPYING
%{_sbindir}/cache_check
%{_sbindir}/cache_dump
%{_sbindir}/cache_metadata_size
%{_sbindir}/cache_repair
%{_sbindir}/cache_restore
%{_sbindir}/cache_writeback
%{_sbindir}/era_check
%{_sbindir}/era_dump
%{_sbindir}/era_invalidate
%{_sbindir}/era_restore
%{_sbindir}/pdata_tools
%{_sbindir}/thin_check
%{_sbindir}/thin_delta
%{_sbindir}/thin_dump
%{_sbindir}/thin_generate_metadata
%{_sbindir}/thin_ll_dump
%{_sbindir}/thin_ls
%{_sbindir}/thin_metadata_size
%{_sbindir}/thin_repair
%{_sbindir}/thin_restore
%{_sbindir}/thin_rmap
%{_sbindir}/thin_scan
%{_sbindir}/thin_show_duplicates
%{_sbindir}/thin_trim
%{_mandir}/man8/cache_check.8%{?ext_man}
%{_mandir}/man8/cache_dump.8%{?ext_man}
%{_mandir}/man8/cache_metadata_size.8%{?ext_man}
%{_mandir}/man8/cache_repair.8%{?ext_man}
%{_mandir}/man8/cache_restore.8%{?ext_man}
%{_mandir}/man8/cache_writeback.8%{?ext_man}
%{_mandir}/man8/era_check.8%{?ext_man}
%{_mandir}/man8/era_dump.8%{?ext_man}
%{_mandir}/man8/era_invalidate.8%{?ext_man}
%{_mandir}/man8/era_restore.8%{?ext_man}
%{_mandir}/man8/thin_check.8%{?ext_man}
%{_mandir}/man8/thin_delta.8%{?ext_man}
%{_mandir}/man8/thin_dump.8%{?ext_man}
%{_mandir}/man8/thin_ls.8%{?ext_man}
%{_mandir}/man8/thin_metadata_size.8%{?ext_man}
%{_mandir}/man8/thin_repair.8%{?ext_man}
%{_mandir}/man8/thin_restore.8%{?ext_man}
%{_mandir}/man8/thin_rmap.8%{?ext_man}
%{_mandir}/man8/thin_trim.8%{?ext_man}

%changelog
* Wed Jun  9 2021 wolfgang.frisch@suse.com
- Link as position-independent executable (bsc#1184124).
* Thu Aug 20 2020 mpluskal@suse.com
- Update to version 0.9.0:
  * New support tools: thin_metadata_{pack,unpack}.
  * thin_check can now check metadata snapshots.
  * some metadata space map bug fixes.
  * thin_check --auto-repair
  * Stop thin_dump --repair/thin_repair ignoring under populated nodes.
- Drop no longer needed patches:
  * boost_168.patch
  * ft-lib_bcache-rename-raise-raise_.patch
* Tue Aug 13 2019 mpluskal@suse.com
- Update to version 0.8.5
  * Mostly internal changes
* Mon Aug  5 2019 stefan.bruens@rwth-aachen.de
- Fix name clash with raise() from signal.h, add
  ft-lib_bcache-rename-raise-raise_.patch
* Wed May 29 2019 mpluskal@suse.com
- Update to version 0.8.3:
  * Mostly internal changes
* Fri Aug 17 2018 adam.majer@suse.de
- boost_168.patch: fix build with Boost 1.68. This version of Boost
  removes compatibility SHA1 header from Uuid library. (bsc#1105088)
* Thu May 31 2018 mpluskal@suse.com
- Update to version 0.7.6:
  * Mostly internal changes
* Wed Mar 14 2018 mpluskal@suse.com
- Modernise spec file with spec-cleaner
* Wed Dec  6 2017 mpluskal@suse.com
- Update to version 0.7.5:
  * Fix a bug that stopped cache_restore working with metadata
    version 2.
* Tue Oct 17 2017 mpluskal@suse.com
- Update to version 0.7.4:
  * No changes provided for this release
* Mon Oct  9 2017 mpluskal@suse.com
- Update to version 0.7.3:
  * Misc internal changes
  * Updates to tests
* Mon Oct  2 2017 mpluskal@suse.com
- Update to version 0.7.2:
  * Misc internal changes
  * Updated documentation and manpages
* Tue Sep  5 2017 mpluskal@suse.com
- Update to version 0.7.1:
  * Misc internal changes
- Enable development tools building
* Mon Aug 28 2017 mmarek@suse.com
- Depend on coreutils for initrd macros (bsc#1055492).
* Sun Jun 18 2017 mpluskal@suse.com
- Update dependencies of scriplets (boo#1044823)
* Mon Jun 12 2017 mpluskal@suse.com
- Update to version 0.7.0:
  * boo#1043043 gh#jthornber/thin-provisioning-tools#79
  * Needed for working with latest lvm2
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Aug 18 2016 mpluskal@suse.com
- Update to version 0.6.3:
  * Update documentation
* Sun Jul 10 2016 mpluskal@suse.com
- Update to version 0.6.2:
  * Fix bug in thin_delta
  * Fix recent regression in thin_repair.
  * Force g++-98 dialect
  * Fix bug in thin_trim
* Thu Feb 11 2016 rguenther@suse.com
- Explicitely build with -std=gnu++98 to avoid all sorts of
  non-C++11 conforming code.
* Sat Feb  6 2016 mpluskal@suse.com
- Update to 0.6.1
  * enable builds with static cxx library
- Make building more verbose
* Fri Jan 29 2016 mpluskal@suse.com
- Conflict with device-mapper < 1.02.115 to avoid file conflicts
* Sun Jan 24 2016 mpluskal@suse.com
- Use optflags when building
- Install to /usr/sbin
- Do not strip installed binaries
- Use scriplets for initrd regeneration
* Fri Jan 22 2016 mpluskal@suse.com
- Update to 0.6.0
  * thin_ls
* Sun Sep 20 2015 mpluskal@suse.com
- Update to 0.5.6
  * era_invalidate may be run on live metadata if the
  - -metadata-snap option is given.
- Changes for 0.5.5
  * You may now give the --metadata_snap option to thin_delta
    without specifying where the snap is.
  * Update man pages to make it clearer that most tools shouldn't
    be run on live metadata.
  * Fix some bugs in the metadata reference counting for
    thin_check.
* Tue Jul 28 2015 mpluskal@suse.com
- Update to 0.5.3
  * thin_delta, thin_trim
  * --clear-needs-check flag for cache_check
  * space map checking for thin check
* Thu Apr 23 2015 mpluskal@suse.com
- Update to 0.4.1
* Wed Feb  6 2013 martin@pluskal.org
- Cleanup .spec
* Wed Feb  6 2013 martin@pluskal.org
- Add patch for ldflags - ldflags.patch
* Tue Jul 31 2012 fehr@suse.de
- Make initial version of package from version 0.1.5 of
  thin-provisioning-tools
